﻿using UnityEngine;

public class PlayerController : MonoBehaviour
{
    /// <summary>
    /// gameiino.com / store.gameiino.com / play.gameiino.com / سایت های ما
    /// t.me/gameiino_learning / t.me/gameiino_play / t.me/gameiino_store / کانال های ما در فضای مجازی
    /// <summary>

    private InputController _controller;
    private Rigidbody _rbody;
    private Transform _camera;

    private Vector2 move;
    private Vector2 rotate;

    [SerializeField] private int jumpValue = 300;
    [SerializeField] private int speed = 4;
    [SerializeField] private int rotateSpeed = 70;

    private void Awake()
    {
        _controller = new InputController();

        _controller.GamePlay.Jump.performed += ctx => Jumping();

        _controller.GamePlay.Fly.performed += ctx => InvokeRepeating("Flying", 0.1f, 0.15f);
        _controller.GamePlay.Fly.canceled += ctx => CancelInvoke("Flying");

        _controller.GamePlay.Move.performed += ctx => move = ctx.ReadValue<Vector2>();
        _controller.GamePlay.Move.canceled += ctx => move = Vector2.zero;

        _controller.GamePlay.Rotate.performed += ctx => rotate = ctx.ReadValue<Vector2>();
        _controller.GamePlay.Rotate.canceled += ctx => rotate = Vector2.zero;
    }

    private void Start()
    {
        _rbody = GetComponent<Rigidbody>();
        _camera = GameObject.FindGameObjectWithTag("Camera").GetComponent<Transform>();
    }

    private void FixedUpdate()
    {
        Rotating();
        Moving();
    }

    private void RotatingCamera()
    {
        Vector3 rc = new Vector3(-rotate.y, 0, 0) * rotateSpeed * Time.deltaTime;
        _camera.transform.Rotate(rc);
    }

    private void Flying()
    {
        _rbody.AddForce(Vector3.up * (jumpValue - 3));
    }

    private void Moving()
    {
        Vector3 m = new Vector3(move.x, 0, move.y) * speed * Time.deltaTime;
        transform.Translate(m);
    }

    private void Rotating()
    {
        Vector3 r = new Vector3(0, rotate.x, 0) * rotateSpeed * Time.deltaTime;
        transform.Rotate(r);
    }

    private void Jumping()
    {
        _rbody.AddForce(Vector3.up * jumpValue);
    }

    private void OnEnable()
    {
        _controller.GamePlay.Enable();
    }

    private void OnDisable()
    {
        _controller.GamePlay.Disable();
    }
}
